import classNames from "classnames";
import React from "react";
import Inputgroup from "./Inputgroup";
import Select from "./Select";
import { useState } from "react";
import { Button } from "./Button/Button";
import { SVGSearch } from "../components/icons";
import TextInputBox from "components/TextInputBox";

type Props = {
  className?: string;
};

const options = [
  { name: "All" },
  { name: "Wade Cooper" },
  { name: "Arlene Mccoy" },
  { name: "Devon Webb" },
  { name: "Tom Cook" },
  { name: "Tanya Fox" },
  { name: "Hellen Schmidt" },
];
const Items = [
  { name: "test" },
  { name: "Wade Cooper" },
  { name: "Arlene Mccoy" },
  { name: "Devon Webb" },
  { name: "Tom Cook" },
  { name: "Tanya Fox" },
  { name: "Hellen Schmidt" },
];
export default function MainSection({
  className,
  ...props
}: Props): JSX.Element {
  const [value, setValue] = useState(options[0]);
  const [selectedPerson, setSelectedPerson] = useState<any>(Items);
  const [query, setQuery] = useState("");

  let filteredItems =
    query === ""
      ? Items
      : Items.filter((item) =>
          item.name
            .toLowerCase()
            .replace(/\s+/g, "")
            .includes(query.toLowerCase().replace(/\s+/g, ""))
        );

  const removeOption = (e: React.SyntheticEvent) => {
    const newSelect = filteredItems.filter(
      (element: any) => element.name !== e
    );
    setSelectedPerson(newSelect);
  };
  return (
    <div className="bg-main bg-center bg-cover bg-origin-border bg-no-repeat h-full py-32 px-2 sm:px-6 md:px-6 lg:px-0">
      <div className="m-auto text-center font-semibold text-4xl ">
        Scientific Library with Free Access
      </div>
      <div className="flex flex-row items-center justify-center space-x-3 pt-2">
        <div className=" text-2xl text-gray-400">Search</div>
        <div className=" text-3xl text-blue-500">320 455</div>
        <div className=" text-2xl text-gray-400">Items</div>
      </div>
      <div className="max-w-xl m-auto pt-16">
        <Inputgroup className="m-0 p-0">
          <div className="flex items-center w-full divide-x-2 divide-solid divide-gray-200">
            <div className="flex w-1/3">
              <Select
                inGroup={true}
                className="w-full top-0"
                options={options}
                value={value}
                onChange={setValue}
                displayValueResolver={(value) => value.name}
              />
            </div>
            <div className="w-full">
              <TextInputBox
                query={query}
                setQuery={setQuery}
                onChange={setSelectedPerson}
                value={selectedPerson}
                queryItems={filteredItems}
                displayValueResolver={(value) => value.name}
                inGroup={true}
                removeOption={removeOption}
              />
            </div>
          </div>
          <div className="pr-0.5">
            <Button
              onClick={() => {
                const Query = { option: value.name, item: selectedPerson.name };
                console.log(Query);
              }}
            >
              <Button.Icon>
                <SVGSearch className="fill-white stroke-white w-4 "></SVGSearch>
              </Button.Icon>
            </Button>
          </div>
        </Inputgroup>
        <div className="mt-7 pr-1 text-right font-semibold text-sm">
          Advanced Search
        </div>
      </div>
    </div>
  );
}
