import classNames from "classnames";
import React from "react";
import "../index.css";
import { Combobox, Transition } from "@headlessui/react";
import { Fragment } from "react";

type Props<T> = {
  removeOption: Function;
  inGroup?: boolean;
  queryItems?: T[];
  query: string;
  setQuery: (element: any) => void;
  disabled?: boolean;
  className?: string;
  value?: T;
  displayValueResolver?: (element: T) => any;
  onChange: (element: T) => void;
} & Omit<
  React.ComponentPropsWithRef<"select">,
  "value" | "onChange" | "queryItems"
>;

const inputStyle = `
  w-full 
  cursor-default
  rounded
  overflow-hidden
  border
  border-solid
  shadow-none
  border-gray-100
  focus:outline-none
  focus:border-gray-200
  hover:border-gray-200 
  py-2 pl-3
  text-sm 
  text-gray-900  
`;

const inputList = `
  absolute z-10 mt-1 w-full max-h-56
  bg-white shadow-lg
  rounded py-1
  overflow-hidden
  focus:outline-none
  text-base 
  sm:text-sm`;

const inputInGroup = [
 `border-none
  hover:none
  active:none
  focus:none
    `,
];

function TextInputBox<T>({
  removeOption,
  inGroup = false, // We should use this flag to choose how we will style our component
  query,
  setQuery,
  className,
  queryItems = [],
  value,
  onChange,
  displayValueResolver,
  disabled,
  ...props
}: Props<T>): JSX.Element {
  return (
    <div className={classNames("", className)}>
      <Combobox value={value} onChange={onChange}>
        <div className="relative">
          <div className="relative w-full  bg-white text-left focus:outline-none sm:text-sm">
            <Combobox.Input
              className={classNames([
                [`${inputStyle}`],
                { [`${inputInGroup}`]: inGroup },
                className,
              ])}
              onChange={(event) => setQuery(event.target.value)}
              placeholder={"Search..."}
              displayValue={(value: T) =>
                displayValueResolver ? displayValueResolver(value) : value
              }
            />
          </div>
          <div>
            {query.length > 0 && (
              <div className={`${inputList}`}>
                <Transition
                  as={Fragment}
                  leave="transition ease-in duration-100"
                  leaveFrom="opacity-100"
                  leaveTo="opacity-0"
                  afterLeave={() => setQuery("")}
                >
                  <Combobox.Options>
                    {queryItems.length === 0 && query !== "" ? (
                      <p >Nothing found.</p>
                    ) : null}
                    {query.length > 0 && (
                      <Combobox.Option value={{ id: null, name: query }} className="cursor-default">
                        query: "{query}"
                      </Combobox.Option>
                    )}
                    {queryItems.map((item: any, id: number) => (
                      <Combobox.Option
                        key={id}
                        className={({ active, selected }) =>
                          classNames(
                            active
                              ? "text-gray-900 bg-blue-50"
                              : "font-normal ",
                            "cursor-default select-none relative py-2 pl-3 pr-9",
                            selected
                              ? "text-gray-900 bg-blue-100"
                              : "font-normal "
                          )
                        }
                        value={item}
                      >
                        <div className="flex items-center justify-between">
                          {`${
                            displayValueResolver
                              ? displayValueResolver(item)
                              : item
                          }`}
                          <span className=" block relative left-0 right-0 text-gray-200">
                            <button
                              onClick={() =>
                                removeOption(
                                  displayValueResolver
                                    ? displayValueResolver(item)
                                    : item
                                )
                              }
                            >
                              x
                            </button>
                          </span>
                        </div>
                      </Combobox.Option>
                    ))}
                  </Combobox.Options>
                </Transition>
              </div>
            )}
          </div>
        </div>
      </Combobox>
    </div>
  );
}
export default TextInputBox;
